@@ -23,12 +23,14 @@ from .type_defs import (
     AssociateBrowserSettingsResponseTypeDef,
     AssociateNetworkSettingsResponseTypeDef,
     AssociateTrustStoreResponseTypeDef,
+    AssociateUserAccessLoggingSettingsResponseTypeDef,
     AssociateUserSettingsResponseTypeDef,
     CreateBrowserSettingsResponseTypeDef,
     CreateIdentityProviderResponseTypeDef,
     CreateNetworkSettingsResponseTypeDef,
     CreatePortalResponseTypeDef,
     CreateTrustStoreResponseTypeDef,
+    CreateUserAccessLoggingSettingsResponseTypeDef,
     CreateUserSettingsResponseTypeDef,
     GetBrowserSettingsResponseTypeDef,
     GetIdentityProviderResponseTypeDef,
@@ -37,6 +39,7 @@ from .type_defs import (
     GetPortalServiceProviderMetadataResponseTypeDef,
     GetTrustStoreCertificateResponseTypeDef,
     GetTrustStoreResponseTypeDef,
+    GetUserAccessLoggingSettingsResponseTypeDef,
     GetUserSettingsResponseTypeDef,
     ListBrowserSettingsResponseTypeDef,
     ListIdentityProvidersResponseTypeDef,
@@ -45,6 +48,7 @@ from .type_defs import (
     ListTagsForResourceResponseTypeDef,
     ListTrustStoreCertificatesResponseTypeDef,
     ListTrustStoresResponseTypeDef,
+    ListUserAccessLoggingSettingsResponseTypeDef,
     ListUserSettingsResponseTypeDef,
     TagTypeDef,
     UpdateBrowserSettingsResponseTypeDef,
@@ -52,6 +56,7 @@ from .type_defs import (
     UpdateNetworkSettingsResponseTypeDef,
     UpdatePortalResponseTypeDef,
     UpdateTrustStoreResponseTypeDef,
+    UpdateUserAccessLoggingSettingsResponseTypeDef,
     UpdateUserSettingsResponseTypeDef,
 )
 
@@ -125,6 +130,16 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#associate_trust_store)
         """
 
+    def associate_user_access_logging_settings(
+        self, *, portalArn: str, userAccessLoggingSettingsArn: str
+    ) -> AssociateUserAccessLoggingSettingsResponseTypeDef:
+        """
+        Associates a user access logging settings resource with a web portal.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.associate_user_access_logging_settings)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#associate_user_access_logging_settings)
+        """
+
     def associate_user_settings(
         self, *, portalArn: str, userSettingsArn: str
     ) -> AssociateUserSettingsResponseTypeDef:
@@ -229,6 +244,17 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#create_trust_store)
         """
 
+    def create_user_access_logging_settings(
+        self, *, kinesisStreamArn: str, clientToken: str = ..., tags: Sequence[TagTypeDef] = ...
+    ) -> CreateUserAccessLoggingSettingsResponseTypeDef:
+        """
+        Creates a user access logging settings resource that can be associated with a
+        web portal.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.create_user_access_logging_settings)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#create_user_access_logging_settings)
+        """
+
     def create_user_settings(
         self,
         *,
@@ -289,6 +315,16 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#delete_trust_store)
         """
 
+    def delete_user_access_logging_settings(
+        self, *, userAccessLoggingSettingsArn: str
+    ) -> Dict[str, Any]:
+        """
+        Deletes user access logging settings.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.delete_user_access_logging_settings)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#delete_user_access_logging_settings)
+        """
+
     def delete_user_settings(self, *, userSettingsArn: str) -> Dict[str, Any]:
         """
         Deletes user settings.
@@ -321,6 +357,14 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#disassociate_trust_store)
         """
 
+    def disassociate_user_access_logging_settings(self, *, portalArn: str) -> Dict[str, Any]:
+        """
+        Disassociates user access logging settings from a web portal.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.disassociate_user_access_logging_settings)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#disassociate_user_access_logging_settings)
+        """
+
     def disassociate_user_settings(self, *, portalArn: str) -> Dict[str, Any]:
         """
         Disassociates user settings from a web portal.
@@ -405,6 +449,16 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_trust_store_certificate)
         """
 
+    def get_user_access_logging_settings(
+        self, *, userAccessLoggingSettingsArn: str
+    ) -> GetUserAccessLoggingSettingsResponseTypeDef:
+        """
+        Gets user access logging settings.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.get_user_access_logging_settings)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_user_access_logging_settings)
+        """
+
     def get_user_settings(self, *, userSettingsArn: str) -> GetUserSettingsResponseTypeDef:
         """
         Gets user settings.
@@ -481,6 +535,16 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#list_trust_stores)
         """
 
+    def list_user_access_logging_settings(
+        self, *, maxResults: int = ..., nextToken: str = ...
+    ) -> ListUserAccessLoggingSettingsResponseTypeDef:
+        """
+        Retrieves a list of user access logging settings.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.list_user_access_logging_settings)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#list_user_access_logging_settings)
+        """
+
     def list_user_settings(
         self, *, maxResults: int = ..., nextToken: str = ...
     ) -> ListUserSettingsResponseTypeDef:
@@ -576,6 +640,20 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#update_trust_store)
         """
 
+    def update_user_access_logging_settings(
+        self,
+        *,
+        userAccessLoggingSettingsArn: str,
+        clientToken: str = ...,
+        kinesisStreamArn: str = ...
+    ) -> UpdateUserAccessLoggingSettingsResponseTypeDef:
+        """
+        Updates the user access logging settings.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.update_user_access_logging_settings)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#update_user_access_logging_settings)
+        """
+
     def update_user_settings(
         self,
         *,
